@@ -266,15 +266,17 @@ class Client:
         Add access to the RPC API for the given user name with the given API key.
         A new user will be created if none is available with given user name.
 
-        Note: only user with admin privileges can use this.
+        Requires superuser.
         """
         return self.__call("activate_rpc_access", [user_name, api_key])
 
-    def add_collection(self, title: str, parent_id: int = None) -> Optional[Dict]:
+    def add_collection(
+        self, title: str, parent_id: int = None, project_id: int = None
+    ) -> Optional[Dict]:
         """
         Create a new collection based on 'title'. If 'parent_id' is set,
-        will create new collection as child of parent. Otherwise, the new
-        collection is created at root.
+        will create new collection as child of parent. Otherwise, project_id
+        is needed to create the new collection at the project's root.
 
         Returns either the serialized new collection of null if parent does
         not exist.
@@ -290,6 +292,7 @@ class Client:
             "descendants_count": 0,
             "descendants_resources_count": 0,
             "parent": null,
+            "project_id": 1,
             "children": null,
             "metas": [],
             "public_access": false,
@@ -297,9 +300,9 @@ class Client:
         }
         ```
         """
-        return self.__call("add_collection", [title, parent_id])
+        return self.__call("add_collection", [title, parent_id, project_id])
 
-    def add_collection_from_path(self, path: str) -> List[Dict]:
+    def add_collection_from_path(self, path: str, project_id: int) -> List[Dict]:
         """
         Will take a path such as '/photos/arts/paintings/'
         and build the corresponding hierarchy of collections. The hierarchy
@@ -320,6 +323,7 @@ class Client:
                 "descendants_count": 0,
                 "descendants_resources_count": 0,
                 "parent": null,
+                "project_id": 1,
                 "children": null,
                 "metas": [],
                 "public_access": false,
@@ -333,6 +337,7 @@ class Client:
                 "descendants_count": 0,
                 "descendants_resources_count": 0,
                 "parent": 1,
+                "project_id": 1,
                 "children": null,
                 "metas": [],
                 "public_access": false,
@@ -346,6 +351,7 @@ class Client:
                 "descendants_count": 0,
                 "descendants_resources_count": 0,
                 "parent": 2,
+                "project_id": 1,
                 "children": null,
                 "metas": [],
                 "public_access": false,
@@ -354,7 +360,7 @@ class Client:
         ]
         ```
         """
-        return self.__call("add_collection_from_path", [path])
+        return self.__call("add_collection_from_path", [path, project_id])
 
     def add_meta_to_collection(
         self, collection_id: int, meta_id: int, meta_value: str
@@ -384,11 +390,11 @@ class Client:
         """
         return self.__call("add_metadata", [title, metas_set_id, metadata_type_id])
 
-    def add_metadataset(self, title: str) -> int:
+    def add_metadataset(self, title: str, project_id: int) -> int:
         """
         Create new metadata set from title.
         """
-        return self.__call("add_metadataset", [title])
+        return self.__call("add_metadataset", [title, project_id])
 
     def add_resource_to_collection(self, resource_id: int, collection_id: int) -> bool:
         """
@@ -408,7 +414,9 @@ class Client:
         """
         return self.__call("add_tag_to_resource", [tag_uid, resource_id])
 
-    def advanced_search(self, search_terms: List[Dict]) -> Dict[str, List]:
+    def advanced_search(
+        self, search_terms: List[Dict], project_id: int
+    ) -> Dict[str, List]:
         """
         Performs a complex search using terms such as 'contains', 'is', 'does_not_contain'.
 
@@ -444,7 +452,7 @@ class Client:
         }
         ```
         """
-        return self.__call("advanced_search", [search_terms])
+        return self.__call("advanced_search", [search_terms, project_id])
 
     def advanced_search_terms(self) -> List[str]:
         """
@@ -582,7 +590,9 @@ class Client:
         """
         return self.__call("change_resource_meta_value", [meta_value_id, meta_value])
 
-    def collection(self, collection_id: int = None) -> Optional[Dict]:
+    def collection(
+        self, collection_id: int = None, project_id: int = None
+    ) -> Optional[Dict]:
         """
         Get a particular collection given its id.
 
@@ -604,7 +614,8 @@ class Client:
         }
         ```
 
-        if collection id is null, will only return the number of collections at root:
+        if collection id is null, will only return the number of collections at root
+        for the given project_id:
 
         ```
         {
@@ -614,7 +625,7 @@ class Client:
         }
         ```
         """
-        return self.__call("collection", [collection_id])
+        return self.__call("collection", [collection_id, project_id])
 
     def collections(
         self,
@@ -624,13 +635,15 @@ class Client:
         limit_to: int = 2000,
         flat_list: bool = False,
         only_published: bool = False,
+        project_id: int = None,
     ) -> List[Dict]:
         """
         Return the user's collections under the parent collection
         specified by 'parent_id'. If 'parent_id' is null, will return
         collections available at root. If 'recursive' is true, will
         return all the descendants recursively in the 'children' key.
-        If recursive is false, 'children' is null.
+        If recursive is false, 'children' is null. If flat_list is True,
+        collections are returned as a flat list and parent_id is ignored.
 
         Example output:
 
@@ -654,15 +667,31 @@ class Client:
         """
         return self.__call(
             "collections",
-            [parent_id, recursive, limit_from, limit_to, flat_list, only_published],
+            [
+                parent_id,
+                recursive,
+                limit_from,
+                limit_to,
+                flat_list,
+                only_published,
+                project_id,
+            ],
         )
 
+    def create_project(self, project_label: str, project_description: str) -> dict:
+        """
+        Create a new project.
+
+        Requires superuser.
+        """
+        return self.__call("create_project", [project_label, project_description])
+
     def deactivate_rpc_access(self, user_name: str, api_key: str) -> bool:
         """
         Deactivate access to the RPC API for the given user name and API key.
         Only the access (API key) is removed, not the user.
 
-        Note: only user with admin privileges can use this.
+        Requires superuser.
         """
         return self.__call("deactivate_rpc_access", [user_name, api_key])
 
@@ -694,6 +723,70 @@ class Client:
         """
         return self.__call("delete_resource", [resource_id])
 
+    def delete_role(self, project_id: int, role_label: str) -> bool:
+        """
+        Delete role within given project.
+
+        Requires superuser
+        """
+        return self.__call("delete_role", [project_id, role_label])
+
+    def delete_tag(self, uid: str) -> bool:
+        """
+        Remove (delete) a tag based on its uid.
+
+        Beware: This will remove ALL associations with the tag.
+        """
+        return self.__call("delete_tag", [uid])
+
+    def has_permission(self, project_id: int, permission: str) -> bool:
+        """
+        Test current user for given permission.
+        """
+        return self.__call("has_permission", [project_id, permission])
+
+    def list_permissions(self) -> List[Dict]:
+        """
+        Lists all available permissions in the application:
+
+        ```
+        [
+            {'id': 1, 'label': 'collection.create'},
+            {'id': 2, 'label': 'collection.read'},
+            {'id': 3, 'label': 'collection.update'},
+            {'id': 4, 'label': 'collection.delete'},
+            {'id': 5, 'label': 'resource.create'},
+            {'id': 6, 'label': 'resource.read'},
+            {'id': 7, 'label': 'resource.update'},
+            {'id': 8, 'label': 'resource.delete'},
+            {'id': 9, 'label': 'metadata.create'},
+            {'id': 10, 'label': 'metadata.read'},
+            {'id': 11, 'label': 'metadata.update'},
+            {'id': 12, 'label': 'metadata.delete'},
+            {'id': 13, 'label': 'metadataset.create'},
+            {'id': 14, 'label': 'metadataset.read'},
+            {'id': 15, 'label': 'metadataset.update'},
+            {'id': 16, 'label': 'metadataset.delete'},
+            {'id': 17, 'label': 'file.create'},
+            {'id': 18, 'label': 'file.read'},
+            {'id': 19, 'label': 'file.update'},
+            {'id': 20, 'label': 'file.delete'},
+            {'id': 21, 'label': 'tag.create'},
+            {'id': 22, 'label': 'tag.read'},
+            {'id': 23, 'label': 'tag.update'},
+            {'id': 24, 'label': 'tag.delete'},
+            {'id': 25, 'label': 'file.download_source'}
+        ]
+        ```
+        """
+        return self.__call("list_permissions", [])
+
+    def list_roles(self, project_id: int) -> List[Dict]:
+        """
+        Fetch all roles defined in the project, no matter the user.
+        """
+        return self.__call("list_roles", [project_id])
+
     def metadata(self, metadata_id: int) -> Optional[Dict]:
         """
         Get one particular metadata given its id.
@@ -707,7 +800,7 @@ class Client:
             "set_id": 1,
             "set_title": "exif metas",
             "rank": 1,
-            "owner": "john",
+            "project_id": 1,
         }
         ```
         """
@@ -729,7 +822,7 @@ class Client:
                 "set_id": 1,
                 "set_title": "exif metas",
                 "rank": 0,
-                "owner": "john",
+                "project_id": 1,
             },
             {
                 "id": 2,
@@ -737,28 +830,28 @@ class Client:
                 "set_id": 1,
                 "set_title": "exif metas",
                 "rank": 1,
-                "owner": "john",
+                "project_id": 1,
             }
         ]
         ```
         """
         return self.__call("metadatas", [metadata_set_id])
 
-    def metadatasets(self) -> List[Dict]:
+    def metadatasets(self, project_id: int) -> List[Dict]:
         """
-        Get the list of all the user's metadata sets.
-        For each metadatas set, the number of metadatas is given in metas_count
+        Get the list of all the project's metadata sets.
+        For each metadatas set, the number of metadatas is given in metas_count.
 
         Example output:
 
         ```
         [
-            {"id": 1, "title": "exif metas", "owner": "john", "metas_count": 23},
-            {"id": 2, "title": "dublin core", "owner": "john", "metas_count": 17}
+            {"id": 1, "title": "exif metas", "project_id": 1, "metas_count": 23},
+            {"id": 2, "title": "dublin core", "project_id": 1, "metas_count": 17}
         ]
         ```
         """
-        return self.__call("metadatasets", [])
+        return self.__call("metadatasets", [project_id])
 
     def metadatatypes(self) -> List[dict]:
         """
@@ -806,6 +899,24 @@ class Client:
         """
         return self.__call("ping", [])
 
+    def projects_user_permissions(self) -> List[Dict]:
+        """
+        Get all rights for the current user.
+
+        Example output:
+
+        ```
+        [
+            {
+                'project': {'id': 7, 'label': 'john doe main project'},
+                'role': {'id': 7, 'label': 'admin', 'permissions': [{"id": 1, "label": "do_anything"}]},
+                'user': 'john doe'
+            }
+        ]
+        ```
+        """
+        return self.__call("projects_user_permissions", [])
+
     def publish_collection(self, collection_id: int) -> bool:
         """
         Mark a collection as public
@@ -838,14 +949,6 @@ class Client:
             "remove_resource_from_collection", [resource_id, collection_id]
         )
 
-    def remove_tag(self, uid: str) -> bool:
-        """
-        Remove (delete) a tag based on its uid.
-
-        Beware: This will remove ALL associations with the tag.
-        """
-        return self.__call("remove_tag", [uid])
-
     def remove_tag_from_collection(self, tag_uid: str, collection_id: int) -> bool:
         """
         Remove tag from a collection based on tag uid and collection id.
@@ -972,7 +1075,19 @@ class Client:
         """
         return self.__call("set_representative_resource", [collection_id, resource_id])
 
-    def set_tag(self, uid: str, label: str = None, ark: str = None) -> dict:
+    def set_role(
+        self, project_id: int, role_label: str, permissions: List[int]
+    ) -> Dict:
+        """
+        Create or update a role on a project, with the given permissions.
+
+        Requires superuser.
+        """
+        return self.__call("set_role", [project_id, role_label, permissions])
+
+    def set_tag(
+        self, uid: str, project_id: int, label: str = None, ark: str = None
+    ) -> dict:
         """
         Get or create a Tag by uid (unique identifier). 'label' is an optional human-readable name.
 
@@ -987,9 +1102,9 @@ class Client:
         }
         ```
         """
-        return self.__call("set_tag", [uid, label, ark])
+        return self.__call("set_tag", [uid, project_id, label, ark])
 
-    def simple_search(self, query: str) -> Dict[str, List]:
+    def simple_search(self, query: str, project_id: int) -> Dict[str, List]:
         """
         Performs a simple search on resources and collections, based on their titles.
 
@@ -1027,7 +1142,7 @@ class Client:
         }
         ```
         """
-        return self.__call("simple_search", [query])
+        return self.__call("simple_search", [query, project_id])
 
     def supported_file_types(self) -> List[Dict]:
         """
@@ -1047,9 +1162,9 @@ class Client:
         """
         return self.__call("supported_file_types", [])
 
-    def tags(self) -> List[dict]:
+    def tags(self, project_id: int) -> List[dict]:
         """
-        Returns all tags available to the current user.
+        Returns all tags available in the project.
 
         Example output:
 
@@ -1070,7 +1185,7 @@ class Client:
         ]
         ```
         """
-        return self.__call("tags", [])
+        return self.__call("tags", [project_id])
 
     def unpublish_collection(self, collection_id: int) -> bool:
         """
@@ -1078,7 +1193,7 @@ class Client:
         """
         return self.__call("unpublish_collection", [collection_id])
 
-    def upload_infos(self, sha256_hash: str) -> Dict:
+    def upload_infos(self, sha256_hash: str, project_id: int) -> Dict:
         """
         Get information for an upload based on the file hash.
 
@@ -1094,4 +1209,4 @@ class Client:
 
         "status" being one of "not available", "available" or "incomplete"
         """
-        return self.__call("upload_infos", [sha256_hash])
+        return self.__call("upload_infos", [sha256_hash, project_id])
